import React, { useEffect } from "react";
import "./index.css";
import {
  FireOutlined,
  ShopOutlined,
  UsergroupAddOutlined,
  SoundOutlined,
  PhoneOutlined,
  ToolOutlined,
  SearchOutlined,
  SafetyCertificateOutlined,
  PoweroffOutlined,
  MoneyCollectOutlined,
  FileSearchOutlined,
  FormOutlined,
} from "@ant-design/icons";
import { Menu, Layout } from "antd";
import { Outlet, useNavigate, useLocation } from "react-router-dom";
import { checkAuth, signOut } from "../../utils/auth";
import Data from "./data";

export default function Op() {
  const { Content, Sider } = Layout;
  const navigate = useNavigate();
  const location = useLocation();

  useEffect(() => {
    const checkToken = async () => {
      const isLogin = await checkAuth();
      if (!isLogin) {
        navigate("/login");
      }
    };
    checkToken();
  }, [location]);
  function getItem(label, key, icon, children, type) {
    return {
      key,
      icon,
      children,
      label,
      type,
    };
  }
  const items = [
    // getItem("资源位管理", "management", <FireOutlined />, [
    //   getItem("推荐排序", "feed"),
    // ]),
    getItem("审核专区", "review", <SafetyCertificateOutlined />, [
      getItem("网红入驻审核", "streamerJoin"),
      getItem("网红实名认证审核", "streamerVerification"),
      // getItem("网红信息修改审核", "streamerProfileReview"),
      getItem("图片机审回查", "imageMachineReview"),
      getItem("文本机审回查", "textMachineReview"),
      getItem("动态机审回查", "postMachineReview"),
      getItem("空间动态审核", "zonePostMachineReview"),
      getItem("已删除动态回捞", "deletedPostReview"),
    ]),
    getItem("网红管理", "streamerManagement", <ShopOutlined />, [
      getItem("网红资料", "streamerInformation"),
      // getItem("网红平台", "streamerPlatform"),
    ]),
    getItem("动态管理", "postManagement", <FormOutlined />, [
      getItem("发布与编辑", "createAndEditPost"),
      getItem("置顶动态", "topPosts"),
    ]),
    getItem("信息查询", "search", <FormOutlined />, [
      getItem("手机号查询", "getPhoneNumber"),
    ]),
    // getItem("用户管理", "userManagement", <UsergroupAddOutlined />),
    getItem("订单管理", "orderManagement", <FileSearchOutlined />, [
      getItem("查询", "ordersQuerry"),
      getItem("退款", "refund"),
    ]),
    getItem("社区治理", "communityManagement", <UsergroupAddOutlined />, [
      getItem("用户封禁", "blockUser"),
    ]),
    getItem(
      "人工充值/提现",
      "manualRechargeAndWithdrawal",
      <MoneyCollectOutlined />
    ),
    getItem("意见反馈", "feedback", <SoundOutlined />),
    getItem("客服回复", "contact", <PhoneOutlined />),
    // getItem("辅助工具", "tools", <ToolOutlined />, [
    //   getItem("上传媒体", "uploadMedia"),
    // ]),
    getItem("退出登录", "signOut", <PoweroffOutlined />),
  ];
  const onClick = (e) => {
    if (e.key === "signOut") {
      signOut();
      return;
    }
    navigate(e.key);
  };
  //获取当前路由
  const parts = location.pathname.split("/");
  const pathName = parts[1];
  return (
    <Layout hasSider>
      <Sider
        style={{
          overflow: "auto",
          height: "100vh",
          position: "fixed",
          left: 0,
          top: 0,
          bottom: 0,
          zIndex: 999,
        }}
      >
        <div onClick={() => navigate("/")} className="op-logo">
          <img src="/images/icon_border.png" alt="" />
          <h2>铁粉空间运营</h2>
        </div>
        <Menu
          onClick={onClick}
          mode="inline"
          items={items}
          theme="dark"
          selectedKeys={pathName}
        />
      </Sider>
      <Layout
        style={{
          marginLeft: 200,
        }}
      >
        <Content
          style={{
            margin: "0 ",
            overflow: "initial",
          }}
        >
          {location.pathname === "/" && <Data />}
          <Outlet />
        </Content>
      </Layout>
    </Layout>
  );
}
